
; VCF-MW 12 6502 Badge Software
; Hardware design by Lee Hart
; Software design by Daryl Rictor
;
; This software is free to use and modify in any non-commercial application.
; Comericial use is prohibited without expressed, written permission from the author.
;
;   ========================
;  | VCF Board LED mapping  |       
;   ========================
;
;--------------------------------
;
; 7-segment LED label
;      ___           
;   F | A | B          
;     |___| 
;   E | G | C
;     |___| 
;       D    
;--------------------------------
;
;  Badge LED data bits as wired           
;  3   2 1   0 x   4 x
;  G   G G   R R   Y Y
; 
;--------------------------------
;
;  Column Scan Address bits as wired
;   0  1  2  3  4  5  6      7    
;   8  8  8  8  8  8  8   RGB LED's    
;
;--------------------------------
;
; Column Scan code table
; Note - these are Active-Low outputs
;
LED_COL	.byte	$FD, $FB, $F7, $EF, $DF, $BF, $7F, $FE
;
;--------------------------------
;
; Segment mapping to IO port
;
; data bits as wired
; 76543210
; SGCADEFB
; conversion to upside down
; SGFDABCE
;
;--------------------------------
;
; Actual mapping to Badge upside down display
;
LA = $08				; Segment A
LB = $04				; Segment B
LC = $02				; Segment C
LD = $10				; Segment D
LE = $01				; Segment E
LF = $20				; Segment F
LG = $40				; Segment G
LS = $80				; serial IO pin
;
;--------------------------------
;
FONT_TABLE					
;
; LS is added to all characters to keep the Serial output inactive (High).
; This table is in ASCII order starting with $20 - Space and ending at $7F
;
	.byte LS			; space
 	.byte LS+LE+LF			; !
	.byte LS+LF+LB			; "
	.byte LS+LF+LB+LA+LG		; #
	.byte LS+LD+LF+LA+LC		; $
	.byte LS+LB+LG			; %
	.byte LS+LD+LB+LG		; &
	.byte LS+LF			; '
	.byte LS+LD+LE+LF+LA		; (
	.byte LS+LD+LB+LA+LC		; )
	.byte LS+LF+LA			; *
	.byte LS+LE+LF+LG		; +
	.byte LS+LD+LC			; ,
	.byte LS+LG			; -
	.byte LS+LD			; .
	.byte LS+LE+LB+LG		; /
	.byte LS+LD+LE+LF+LB+LA+LC	; 0
	.byte LS+LB+LC			; 1
	.byte LS+LD+LE+LB+LA+LG		; 2
	.byte LS+LD+LB+LA+LG+LC		; 3
	.byte LS+LF+LB+LG+LC		; 4
	.byte LS+LD+LF+LA+LG+LC		; 5
	.byte LS+LD+LE+LF+LA+LG+LC	; 6
	.byte LS+LB+LA+LC		; 7
	.byte LS+LD+LE+LF+LB+LA+LG+LC	; 8
	.byte LS+LF+LB+LA+LG+LC		; 9
	.byte LS+LD+LA			; :
	.byte LS+LD+LA+LC		; ;
	.byte LS+LD+LE			; <
	.byte LS+LD+LG			; =
	.byte LS+LD+LC			; >
	.byte LS+LE+LB+LA+LG		; ?
	.byte LS+LD+LE+LB+LA+LG+LC	; @
	.byte LS+LE+LF+LB+LA+LG+LC	; A
	.byte LS+LD+LE+LF+LG+LC		; B
	.byte LS+LD+LE+LF+LA		; C
	.byte LS+LD+LE+LB+LG+LC		; D
	.byte LS+LD+LE+LF+LA+LG		; E
	.byte LS+LE+LF+LA+LG		; F
	.byte LS+LD+LE+LF+LA+LC		; G
	.byte LS+LE+LF+LB+LG+LC		; H
	.byte LS+LB+LC			; I
	.byte LS+LD+LE+LB+LC		; J
	.byte LS+LE+LF+LB+LG		; K
	.byte LS+LD+LE+LF		; L
	.byte LS+LE+LB+LG+LC		; M
	.byte LS+LE+LF+LB+LA+LC		; N
	.byte LS+LD+LE+LF+LB+LA+LC	; O
	.byte LS+LE+LF+LB+LA+LG		; P
	.byte LS+LF+LB+LA+LG+LC		; Q
	.byte LS+LE+LG			; R
	.byte LS+LD+LF+LA+LG+LC		; S
	.byte LS+LE+LF+LA		; T
	.byte LS+LD+LE+LF+LB+LC		; U
	.byte LS+LD+LE+LF+LB+LC		; V
	.byte LS+LD+LE+LF+LB+LC		; W
	.byte LS+LG+LC			; X
	.byte LS+LD+LF+LB+LG+LC		; Y
	.byte LS+LD+LE+LB+LA		; Z
	.byte LS+LD+LE+LF+LA		; [
	.byte LS+LF+LG+LC		; \
	.byte LS+LD+LB+LA+LC		; ]
	.byte LS+LF+LB+LA		; ^
	.byte LS+LD			; _
	.byte LS+LB			; `
	.byte LS+LD+LE+LB+LA+LG+LC	; a
	.byte LS+LD+LE+LF+LG+LC		; b
	.byte LS+LD+LE+LG		; c
	.byte LS+LD+LE+LB+LG+LC		; d
	.byte LS+LD+LE+LF+LB+LA+LG	; e
	.byte LS+LE+LF+LA+LG		; f
	.byte LS+LD+LF+LB+LA+LG+LC	; g
	.byte LS+LE+LF+LG+LC		; h
	.byte LS+LC			; i
	.byte LS+LD+LE+LB+LC		; j
	.byte LS+LE+LF+LB+LG		; k
	.byte LS+LE+LF			; l
	.byte LS+LE+LB+LG+LC		; m
	.byte LS+LE+LG+LC		; n
	.byte LS+LD+LE+LG+LC		; o
	.byte LS+LE+LF+LB+LA+LG		; p
	.byte LS+LF+LB+LA+LG+LC		; q
	.byte LS+LE+LG			; r
	.byte LS+LD+LF+LA+LG+LC		; s
	.byte LS+LD+LE+LF+LG		; t
	.byte LS+LD+LE+LC		; u
	.byte LS+LD+LE+LC		; v
	.byte LS+LD+LE+LC		; w
	.byte LS+LG+LC			; x
	.byte LS+LD+LF+LB+LG+LC		; y
	.byte LS+LD+LE+LB+LA		; z
	.byte LS+LD+LE+LF+LA		; {
	.byte LS+LE+LF			; |
	.byte LS+LD+LB+LA+LC		; }
	.byte LS+LD+LA+LG		; ~
	.byte LS+LD+LE+LB+LG+LC		; 

